@@ -1,43 +1,47 @@
 #ifndef _HYDRA_H
 
 #ifndef NESSUS_PLUGIN
- #include <stdio.h>
- #include <string.h>
- #include <unistd.h>
- #include <stdlib.h>
- #include <signal.h>
- #include <string.h>
- #include <strings.h>
- #include <time.h>
- #include <sys/time.h>
- #include <sys/types.h>
- #include <sys/socket.h>
- #include <netdb.h>
- #include <netinet/in.h>
- #include <arpa/inet.h>
- #include <fcntl.h>
- #include <ctype.h>
- #include <sys/resource.h>
- #include <sys/wait.h>
+#include <stdio.h>
+#include <string.h>
+#include <unistd.h>
+#include <stdlib.h>
+#include <signal.h>
+#include <string.h>
+#include <strings.h>
+#include <time.h>
+#include <sys/time.h>
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <netdb.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
+#include <fcntl.h>
+#include <ctype.h>
+#include <sys/resource.h>
+#include <sys/wait.h>
+#include <errno.h>
 #endif
 
 #ifdef HAVE_OPENSSL
- #define HYDRA_SSL
+#define HYDRA_SSL
 #endif
 #ifdef HAVE_SSL
- #ifndef HYDRA_SSL
-  #define HYDRA_SSL
- #endif
+#ifndef HYDRA_SSL
+#define HYDRA_SSL
+#endif
 #endif
 
 #define OPTION_SSL 1
 
+#define PORT_NOPORT     -1
 #define PORT_FTP	21
 #define PORT_FTP_SSL	990
 #define PORT_TELNET	23
 #define PORT_TELNET_SSL	992
 #define PORT_HTTP	80
 #define PORT_HTTP_SSL	443
+#define PORT_HTTP_PROXY 3128
+#define PORT_HTTP_PROXY_SSL 3128
 #define PORT_POP3	110
 #define PORT_POP3_SSL	995
 #define PORT_NNTP	119
@@ -60,6 +64,16 @@
 #define PORT_PCNFS_SSL	-1
 #define PORT_MYSQL      3306
 #define PORT_MYSQL_SSL  3306
+#define PORT_MSSQL	1433
+#define PORT_MSSQL_SSL	1433
+#define PORT_SAPR3      -1
+#define PORT_SAPR3_SSL  -1
+#define PORT_SSH        22
+#define PORT_SSH_SSL    22
+
+#ifndef INET_ADDRSTRLEN
+#define INET_ADDRSTRLEN 16
+#endif
 
 #define _HYDRA_H
 #endif
